#!/usr/bin/perl

use DataOneLdap;
use strict;

use Getopt::Long();

sub usage {
   my $message = $_[0];
   if (defined $message && length $message) {
      $message .= "\n"
         unless $message =~ /\n$/;
   }

   my $command = $0;
   $command =~ s#^.*/##;

   print STDERR (
      $message,
      "usage: $command [--help] --id nodeId\n" 
   );

   die("\n")
}

my $nodeid;
my $help;

Getopt::Long::GetOptions(
   'id=s' => \$nodeid,
   'help!' => \$help
) or usage("Invalid commmand line options.");
 
usage() if (defined $help);

usage("The identifier of the node must be specified.")
   unless (defined $nodeid) ;

my $d1Ldap = new DataOneLdap();

my $ldap = $d1Ldap->connect();

my $mesg = $ldap->search(  filter=>"(cn=$nodeid)", base=>"dc=dataone,dc=org");

my @entries = $mesg->entries;
foreach my $entry (@entries) 
	{
	my $dn = $entry->dn();
	print "DN = $dn\n";
	$ldap->modify($dn, replace => {'d1NodeApproved', 'TRUE'});
	}

$ldap->unbind;

